<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>GB2::LocalWorkflow::SiteconBuildPrompter</name>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="100"/>
        <source>For each MSA from &lt;u&gt;%1&lt;/u&gt;,</source>
        <translation>Для каждого выравнивания из &lt;u&gt;%1&lt;/u&gt;,</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="101"/>
        <source>%1 build SITECON model.</source>
        <translation>%1 построить профайл SITECON.</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconBuildWorker</name>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="62"/>
        <source>Build SITECON model</source>
        <translation>Построить SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="143"/>
        <source>Built SITECON model from: %1</source>
        <translation>Построен профайл SITECON из %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="40"/>
        <source>Input alignment</source>
        <translation>Входное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="46"/>
        <source>Sitecon model</source>
        <translation>Профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="41"/>
        <source>Origin</source>
        <translation>Происхождение</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="51"/>
        <source>Window size, bp</source>
        <translation>Размер окна</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="52"/>
        <source>Calibration length</source>
        <translation>Длина калибрации</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="53"/>
        <source>Random seed</source>
        <translation>Затравка</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="54"/>
        <source>Weight algorithm</source>
        <translation>Алгоритм весов</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="40"/>
        <source>Input multiple sequence alignment for building statistical model.</source>
        <translation>Входное множественное выравнивание для построения статистической модели данного ССТФ.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="41"/>
        <source>Location of input alignment, used as optional hint for model description.</source>
        <translation>Адрес множественного выравнивания, используется для описания выходного профайла SITECON.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="46"/>
        <source>Produced statistical model of specified TFBS data.</source>
        <translation>Произведённый профайл SITECON.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="63"/>
        <source>Builds statistical profile for SITECON. The SITECON is a program for probabilistic recognition of transcription factor binding sites.</source>
        <translation>Строит статистический профайл для поиска ССТФ при помощи пакета SITECON.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="85"/>
        <source>None</source>
        <translation>Без весов</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="86"/>
        <source>Algorithm2</source>
        <translation>Алгоритм №2</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconReadPrompter</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="151"/>
        <source>Read model(s) from &lt;u&gt;%1&lt;/u&gt;</source>
        <translation>Загрузить профайлы SITECON из &lt;u&gt;%1&lt;/u&gt;.</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconReader</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="192"/>
        <source>Loaded SITECON model from %1</source>
        <translation>Загружен профайл SITECON из %1</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconSearchPrompter</name>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="103"/>
        <source>For each sequence from &lt;u&gt;%1&lt;/u&gt;,</source>
        <translation>Для каждой последовательности из &lt;u&gt;%1&lt;/u&gt;,</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="115"/>
        <source>%1 search transcription factor binding sites (TFBS) %2.&lt;br&gt;Recognize sites with &lt;u&gt;similarity %3%&lt;/u&gt;, process &lt;u&gt;%4&lt;/u&gt;.&lt;br&gt;Output the list of found regions annotated as &lt;u&gt;%5&lt;/u&gt;.</source>
        <translation>%1 искать сайты связывания ТФ %2.&lt;br&gt;Распознавать сайты с достоверностью &lt;u&gt;не менее %3%&lt;/u&gt;, рассматривать &lt;u&gt;%4 стренды&lt;/u&gt;.&lt;br&gt;Выдать список найденных регионов аннотированных как &lt;u&gt;%5&lt;/u&gt;.</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="104"/>
        <source>with all profiles provided by &lt;u&gt;%1&lt;/u&gt;,</source>
        <translation>со всеми профайлами из &lt;u&gt;%1&lt;/u&gt;,</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconSearchWorker</name>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="88"/>
        <location filename="../src/SiteconSearchWorker.cpp" line="110"/>
        <source>both strands</source>
        <translation>все</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="89"/>
        <location filename="../src/SiteconSearchWorker.cpp" line="111"/>
        <source>direct strand</source>
        <translation>только прямые</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="90"/>
        <location filename="../src/SiteconSearchWorker.cpp" line="112"/>
        <source>complement strand</source>
        <translation>только комплиментарные</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="45"/>
        <source>Sitecon Model</source>
        <translation>Профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="46"/>
        <source>Sequence</source>
        <translation>Входная последовательность</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="47"/>
        <source>SITECON annotations</source>
        <translation>Аннотированные ССТФ</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="53"/>
        <source>Result annotation</source>
        <translation>Аннотации</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="54"/>
        <source>Search in</source>
        <translation>Направление</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="168"/>
        <source>Search TFBS in %1</source>
        <translation>Поиск ССТФ в %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="172"/>
        <source>Bad sequence supplied to SiteconSearch: %1</source>
        <translation>Неправильная последовательность для SITECON поиска : %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="196"/>
        <source>Found %1 TFBS</source>
        <translation>Найдено %1 возможных сайтов связывания ТФ</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="45"/>
        <source>Profile data to search with.</source>
        <translation>Профайл SITECON характеризующий искомые сайты.</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="46"/>
        <source>Input nucleotide sequence to search in.</source>
        <translation>Входная нуклеотидная последовательность для поиска.</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="47"/>
        <source>Annotations marking found TFBS sites.</source>
        <translation>Аннотации маркирующие найденные регионы.</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="53"/>
        <source>Annotation name for marking found regions</source>
        <translation>Имя аннотации для разметки найденных регионов.</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="54"/>
        <source>Which strands should be searched: direct, complement or both.</source>
        <translation>В каких стрендах последовательности следует искать ССТФ: прямых, комплементарных или всех.</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="67"/>
        <source>Search TFBS</source>
        <translation>Поиск ССТФ</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="68"/>
        <source>Searches each input sequence for transcription factor binding sites significantly similar to specified SITECON profiles. In case several profiles were supplied, searches with all profiles one by one and outputs merged set of annotations for each sequence.</source>
        <translation>Поиск сайтов связывания транскрипционных факторов (ССТФ). В каждой нуклеотидной последовательности, поданной на вход задачи, ищутся значимые совпадения с указанными профайлами SITECON. Найденные регионы выдаются в виде набора аннотаций. Профайлов может быть несколько, поиск отработает для каждого профайла и выдаст общий набор аннотаций для каждой последовательности.&lt;p&gt; Протеиновые последовательности на входе допустимы но игнорируются.</translation>
    </message>
    <message>
        <source>Minimal threshold</source>
        <translation type="obsolete">Достоверность</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="55"/>
        <source>Min score</source>
        <translation>Мин оценка</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="56"/>
        <source>Min Err1</source>
        <translation>Мин ошибка 1 рода</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="56"/>
        <source>Alternative setting for filtering results, minimal value of Error type I.&lt;br&gt;Note that all thresholds (by score, by err1 and by err2) are applied when filtering results.</source>
        <translation>Фильтрация результатов по значению ошибки I рода. &lt;br&gt;Учтите что применяются все фильтры (по оценке и ошибкам 1, 2 рода).</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="58"/>
        <source>Max Err2</source>
        <translation>Макс ошибка 2 рода</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="58"/>
        <source>Alternative setting for filtering results, max value of Error type II.&lt;br&gt;Note that all thresholds (by score, by err1 and by err2) are applied when filtering results.</source>
        <translation>Фильтрация результатов по значению ошибки II рода. &lt;br&gt;Учтите что применяются все фильтры (по оценке и ошибкам 1, 2 рода).</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconWritePrompter</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="161"/>
        <source>Save the profile(s) from &lt;u&gt;%1&lt;/u&gt; to %2.</source>
        <translation>Сохранить все профайлы из &lt;u&gt;%1&lt;/u&gt; в %2.</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::SiteconWriter</name>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="210"/>
        <source>Unspecified URL for writing Sitecon</source>
        <translation>Не укзазан адрес для записи модели SITECON.</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="225"/>
        <source>Writing SITECON model to %1</source>
        <translation>Запись профайла SITECON в %1</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconADVContext</name>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="99"/>
        <source>run_sitecon</source>
        <translation>SITECON: Искать сайты связывания ТФ  ...</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconBuildDialogController</name>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="45"/>
        <source>select_file_with_alignment</source>
        <translation>Выбор выравнивания для построения модели SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="81"/>
        <source>illegal_in_file_name</source>
        <translation>Укажите входной файл выравнивания</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="86"/>
        <source>illegal_out_file_name</source>
        <translation>Укажите файл результирующей модели</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="92"/>
        <source>error</source>
        <translation>Внимание</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="104"/>
        <source>starting_calibration_process</source>
        <translation>Начинается построение</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="107"/>
        <source>hide_button</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="108"/>
        <source>cancel_button</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="121"/>
        <source>build_finished_with_errors_%1</source>
        <translation>Построение завершено с ошибкой: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="123"/>
        <source>build_canceled</source>
        <translation>Построение отменено</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="125"/>
        <source>build_finished_successfuly</source>
        <translation>Построение успешно завершено</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="127"/>
        <source>start_button</source>
        <translation>Построить</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="128"/>
        <source>close_button</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="134"/>
        <source>running_state_%1_progress_%2%</source>
        <translation>Прогресс %2%: %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="55"/>
        <source>Select file to save model to...</source>
        <translation>Выбор файла для сохранения профайла</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconBuildTask</name>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="149"/>
        <source>build_sitecon_model</source>
        <translation>Построение модели SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="159"/>
        <source>alignment_has_gaps</source>
        <translation>Выравнивание содержит пропуски</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="163"/>
        <source>alignment_is_empty</source>
        <translation>Выравнивание не содержит данных</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="167"/>
        <source>alignment_is_not_nucleic</source>
        <translation>Поддерживаются только нуклеотидные выравнивания</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="171"/>
        <source>window_greater_then_length</source>
        <translation>Размер окна больше длины последовательности</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="185"/>
        <source>calculating_ave_disp_matrix</source>
        <translation>расчёт матрицы средних и дисперсии</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="190"/>
        <source>calculating_weights</source>
        <translation>расчёт весов</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="196"/>
        <source>calculating_firstTypeErr</source>
        <translation>расчёт ошибки ошибки 1-го рода</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="202"/>
        <source>calculating_second_type_err</source>
        <translation>расчёт ошибки ошибки 2-го рода</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconBuildToFileTask</name>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="210"/>
        <source>build_sitecon_model</source>
        <translation>Построение модели SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="220"/>
        <source>input_format_error</source>
        <translation>Неверный формат файла</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="228"/>
        <source>loading_ali</source>
        <translation>загрузка выравнивания</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildDialogController.cpp" line="247"/>
        <source>no_alignments_found</source>
        <translation>Выравнивание не найдено</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconIO</name>
    <message>
        <location filename="../src/SiteconIO.cpp" line="79"/>
        <source>not_sitecon_model_file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="118"/>
        <source>error_parsing_settings_line_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="129"/>
        <source>error_parsing_settings_window_size_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="142"/>
        <source>error_parsing_calibration_len_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="148"/>
        <source>error_parsing_rseed_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="154"/>
        <location filename="../src/SiteconIO.cpp" line="160"/>
        <source>error_parsing_nsequence_in_ali_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="168"/>
        <source>illegal_weight_alg_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="180"/>
        <source>model_size_not_matched_%1_expected_%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="213"/>
        <source>property_not_recognized_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="229"/>
        <source>error_parsing_matrix_val_%1_in_line_%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="247"/>
        <source>error_parsing_errors_line_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="256"/>
        <location filename="../src/SiteconIO.cpp" line="261"/>
        <source>error_parsing_error_val_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="265"/>
        <source>illegal_err_val_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="275"/>
        <source>error_parsing_file_line_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="284"/>
        <source>ave_props_in_file_%1_not_matched_sdev_props_%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="289"/>
        <source>ave_props_in_file_%1_not_matched_weight_props_%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="294"/>
        <source>props_in_file_%1_not_matched_actual_props_%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="322"/>
        <source>error_info_not_complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="329"/>
        <source>model_verification_error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="203"/>
        <source>duplicate_prop_%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="39"/>
        <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
        <location filename="../src/SiteconIOWorkers.cpp" line="114"/>
        <source>Sitecon model</source>
        <translation>Профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="53"/>
        <location filename="../src/SiteconIOWorkers.cpp" line="99"/>
        <source>Location</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="116"/>
        <source>Read Sitecon model</source>
        <translation>Читать профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
        <source>Write Sitecon model</source>
        <translation>Сохранить профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="45"/>
        <source>SITECON</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/SiteconIO.cpp" line="22"/>
        <source>Sitecon models</source>
        <translation>Профайлы SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="53"/>
        <source>Location of the data file(s).</source>
        <translation>Адрес файла данных</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="99"/>
        <source>Location hint for the target file.</source>
        <translation>Адрес целевого файла</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="105"/>
        <source>Input Sitecon model</source>
        <translation>Входящий профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="107"/>
        <source>Saves all input SITECON profiles to specified location.</source>
        <translation>Сохраняет все входящие профайлы SITECON в указанный файл.</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="114"/>
        <source>Loaded SITECON profile data.</source>
        <translation>Загруженный профайл SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconIOWorkers.cpp" line="116"/>
        <source>Reads SITECON profiles from file(s). The files can be local or Internet URLs.</source>
        <translation>Считывает профайл(ы) SITECON из указанных файлов. Файлы могут быть локальными либо адресами Интернет.</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconPlugin</name>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="38"/>
        <source>sitecon_plugin</source>
        <translation>SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="38"/>
        <source>sitecon_plugin_desc</source>
        <translation>Адаптированная версия программы SITECON: поиск сайтов связывания транскрипционных факторов. Включает около сотни откалиброванных моделей ССТФ. 
Домашняя страница проекта: http://wwwmgs.bionet.nsc.ru/cgi-bin/mgs/sitecon/sitecon.pl?stage=0</translation>
    </message>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="44"/>
        <source>sitecon_build</source>
        <translation>Построить модель SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconPlugin.cpp" line="50"/>
        <source>sitecon_menu</source>
        <translation>SITECON (Сайты Связывания ТФ)</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconReadTask</name>
    <message>
        <location filename="../src/SiteconIO.h" line="31"/>
        <source>Read SITECON model</source>
        <translation>Загрузка модели SITECON</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconSearchDialogController</name>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="122"/>
        <source>cancel_button</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="122"/>
        <source>close_button</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="134"/>
        <source>progress_%1%_</source>
        <translation>Прогресс  %1%</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="136"/>
        <source>%1_results_found.</source>
        <translation>найдено %1</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="155"/>
        <source>select_file_with_model</source>
        <translation>Выбор модели SITECON</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="164"/>
        <location filename="../src/SiteconSearchDialogController.cpp" line="262"/>
        <location filename="../src/SiteconSearchDialogController.cpp" line="273"/>
        <location filename="../src/SiteconSearchDialogController.cpp" line="286"/>
        <source>error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="199"/>
        <source>%1%	err1=%2	err2=%3</source>
        <translation>%1%	err1=%2	err2=%3</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="262"/>
        <source>model not selected</source>
        <translation>Укажите файл модели</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="273"/>
        <source>range_is_too_small</source>
        <translation>Слишком маленький регион для поиска</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="286"/>
        <source>error_parsing_min_score</source>
        <translation>Неразборчивая строка минимальной ошибки</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="351"/>
        <source>complement_strand</source>
        <translation>комплeментарный</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchDialogController.cpp" line="351"/>
        <source>direct_strand</source>
        <translation>прямой</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconSearchTask</name>
    <message>
        <location filename="../src/SiteconSearchTask.cpp" line="6"/>
        <source>sitecon_search</source>
        <translation>Поиск ССТФ</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchTask.cpp" line="19"/>
        <source>sitecon_search_parallel</source>
        <translation>Параллельный поиск ССТФ</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchTask.cpp" line="39"/>
        <source>internal_error_invalid_psum:%1</source>
        <translation>Внутренняя ошибка, неверная сумма: %1</translation>
    </message>
</context>
<context>
    <name>GB2::SiteconWriteTask</name>
    <message>
        <location filename="../src/SiteconIO.h" line="44"/>
        <source>Save SITECON model</source>
        <translation>Сохранение модели SITECON</translation>
    </message>
</context>
<context>
    <name>SiteconBuildDialog</name>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="13"/>
        <source>sitecon_build_caption</source>
        <translation>Построение модели SITECON</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="21"/>
        <source>input_ali</source>
        <translation>Входное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="31"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="48"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="38"/>
        <source>out_profile</source>
        <translation>Результирующая модель</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="57"/>
        <source>options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="66"/>
        <source>window_size</source>
        <translation>Размер окна</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="98"/>
        <source>bp</source>
        <translation>нукл</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="117"/>
        <source>calibration_random_seed</source>
        <translation>Случайная затравка</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="168"/>
        <source>calibration_sequence_len</source>
        <translation>Длина калибровочной последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="201"/>
        <source>       100 Kb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="206"/>
        <source>       500 Kb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="211"/>
        <source>         1 Mb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="216"/>
        <source>         5 Mb</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="227"/>
        <source>weight_alg</source>
        <translation>Алгоритм весов</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="285"/>
        <source>default_status</source>
        <translation> </translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="305"/>
        <source>start_button</source>
        <translation>Построить</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="312"/>
        <source>cancel_butotn</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="254"/>
        <source>       None</source>
        <translation>Без весов</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="259"/>
        <source>  Algorithm N2</source>
        <translation>Алгоритм №2</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="51"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="63"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="92"/>
        <source>win_tip</source>
        <translation>Размер окна должен быть не короче консенсуса для данного сайта но не более длины выравнивания.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="52"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="165"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="188"/>
        <source>seq_len_tip</source>
        <translation>Длина случайных синтетических последовательностей для калибрации профайла. Не должна быть меньше размера окна.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="53"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="114"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="143"/>
        <source>seed_tip</source>
        <translation>Случайная затравка. Использование этого параметра полезно для воспроизведения результата калибрации.</translation>
    </message>
    <message>
        <location filename="../src/SiteconBuildWorker.cpp" line="54"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="224"/>
        <location filename="../src/ui/SiteconBuildDialog.ui" line="247"/>
        <source>algo_tip</source>
        <translation>В большинстве случаев алгоритм без весов вполне адекватен. Использование других алгоритмов может улучшить качество распознавания в отдельных случаях.</translation>
    </message>
</context>
<context>
    <name>SiteconSearchDialog</name>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="13"/>
        <source>sitecon_search_title</source>
        <translation>Поиск сайтов связывания ТФ по модели SITECON</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="21"/>
        <source>sitecon_model_file</source>
        <translation>Модель</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="35"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="45"/>
        <source>error_level</source>
        <translation>Минимальная ошибка</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="75"/>
        <source>strand_group</source>
        <translation>Направление</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="81"/>
        <source>strand_both</source>
        <translation>Все</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="94"/>
        <source>strand_direct_wit</source>
        <translation>Искать ССТФ только в прямой последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="97"/>
        <source>strand_direct_label</source>
        <translation>Только прямые</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="113"/>
        <source>strand_complement_wit</source>
        <translation>Искать ССТФ только в комплeментарной последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="116"/>
        <source>strand_complement_label</source>
        <translation>Только комплeментарные</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="129"/>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="264"/>
        <source>range</source>
        <translation>Регион</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="137"/>
        <source>sequence_range</source>
        <translation>Вся последовательность</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="164"/>
        <source>selection_range</source>
        <translation>Селектированный регион</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="188"/>
        <source>custom_range</source>
        <translation>Указанный регион</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="221"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="269"/>
        <source>strand</source>
        <translation>Стренд</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="274"/>
        <source>psum</source>
        <translation>Оценка</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="279"/>
        <source>err1</source>
        <translation>Ошибка 1-го рода</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="284"/>
        <source>err2</source>
        <translation>Ошибка 2-го рода</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="294"/>
        <source>clear_results</source>
        <translation>Сбросить результаты</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="301"/>
        <source>save_as_annotations</source>
        <translation>Сохранить результаты</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="325"/>
        <source>status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="345"/>
        <source>search</source>
        <translation>Искать</translation>
    </message>
    <message>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="352"/>
        <source>cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/SiteconSearchWorker.cpp" line="55"/>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="42"/>
        <location filename="../src/ui/SiteconSearchDialog.ui" line="58"/>
        <source>min_err_tip</source>
        <translation>Нижний предел качества распознавания, величина более 60% но меньше 100%. Слишком низкий предел приведёт к нахождению большого числа ложных сигналов, чрезмерно высокий отбросит качественные результаты.</translation>
    </message>
</context>
</TS>
